@@ -1,7 +1,7 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
 # For details: https://github.com/gaogaotiantian/objprint/blob/master/NOTICE.txt
 
-__version__ = "0.1.2"
+__version__ = "0.1.4"
 
 
 from .objprint import ObjPrint
@@ -10,6 +10,7 @@ from .decorator import add_objprint
 _objprint = ObjPrint()
 op = objprint = _objprint.objprint
 objstr = _objprint.objstr
+objjson = _objprint.objjson
 config = _objprint.config
 install = _objprint.install
 
@@ -17,6 +18,7 @@ install = _objprint.install
 __all__ = [
     "op",
     "objstr",
+    "objjson",
     "config",
     "add_objprint",
     "install"
